# __init__.py
# Copyright (C) 2012 the ColanderAlchemy authors and contributors
# <see AUTHORS file>
#
# This module is part of ColanderAlchemy and is released under
# the MIT License: http://www.opensource.org/licenses/mit-license.php

from types import SQLAlchemyMapping
from utils import MappingRegistry

__all__ = ['SQLAlchemyMapping', 'MappingRegistry']
